% This script generates nice plots for the impulse responses, with the HPD
% regions shaded.
%
% NOTICE:
% -------
% Permission is hereby granted to use this code freely for academic
% purposes only, provided that the paper is duly cited as:
%
% Eisenstat, E., Chan, J. C. C. and R. W. Strachan (2015). "Stochastic Model
% Specification Search for Time-Varying Parameter VARs," Econometric
% Reviews, forthcoming.
%
% Any other use of this code, particularly for comercial purposes, is
% strictly prohibited without the prior written consent of the authors.
% Furthermore, this code comes without technical support of any kind.  It
% is expected to reproduce the results reported in the paper.  However,
% beware that the notation may not the match text.  Likewise, it is not
% gauranteed to work under different hardware and / or software settings,
% other than those used for its original design and implementation.
%
% Under no circumstances will the authors be held responsible for any use
% (or misuse) of this code in any way.  If you do not agree to the above,
% you do not have permission to use this code.

figure, box on; ylim( [-1.50001, 1.50001] );
set( gca, 'FontSize', 16, 'FontName', 'Times New Roman' );
hold on;
hdl = area( 0:s, [squeeze( IRsort( 1, 2, :, bands( 1 ) ) ) * scale_adj( 1, 2 ) ...
             diff( squeeze( IRsort( 1, 2, :, bands( [1 3] ) ) ) * scale_adj( 1, 2 ), 1, 2 )], ...
             'EdgeColor', 'none' );
set( hdl( 1 ), 'FaceColor', 'none' );
set( hdl( 2 ), 'FaceColor', [0.9, 0.9, 0.9] );
plot( 0:s, squeeze( IRsort( 1, 2, :, bands( [1 3] ) ) ) * scale_adj( 1, 2 ), 'k:', 'LineWidth', 1.5 );
plot( 0:s, squeeze( IRsort( 1, 2, :, bands( 2 ) ) ) * scale_adj( 1, 2 ), 'k-', 'LineWidth', 3 );
hold off;

figure, box on; ylim( [0.39999, 1.20001] );
set( gca, 'FontSize', 16, 'FontName', 'Times New Roman' );
hold on;
hdl = area( 0:s, [squeeze( IRsort( 2, 2, :, bands( 1 ) ) ) * scale_adj( 2, 2 ) ...
             diff( squeeze( IRsort( 2, 2, :, bands( [1 3] ) ) ) * scale_adj( 2, 2 ), 1, 2 )], ...
             'EdgeColor', 'none' );
set( hdl( 1 ), 'FaceColor', 'none' );
set( hdl( 2 ), 'FaceColor', [0.9, 0.9, 0.9] );
plot( 0:s, squeeze( IRsort( 2, 2, :, bands( [1 3] ) ) ) * scale_adj( 2, 2 ), 'k:', 'LineWidth', 1.5 );
plot( 0:s, squeeze( IRsort( 2, 2, :, bands( 2 ) ) ) * scale_adj( 2, 2 ), 'k-', 'LineWidth', 3 );
hold off;

figure, box on; ylim( [-0.60001, 0.40001] );
set( gca, 'FontSize', 16, 'FontName', 'Times New Roman' );
hold on;
hdl = area( 0:s, [squeeze( IRsort( 3, 2, :, bands( 1 ) ) ) * scale_adj( 3, 2 ) ...
             diff( squeeze( IRsort( 3, 2, :, bands( [1 3] ) ) ) * scale_adj( 3, 2 ), 1, 2 )], ...
             'EdgeColor', 'none' );
set( hdl( 1 ), 'FaceColor', 'none' );
set( hdl( 2 ), 'FaceColor', [0.9, 0.9, 0.9] );
plot( 0:s, squeeze( IRsort( 3, 2, :, bands( [1 3] ) ) ) * scale_adj( 3, 2 ), 'k:', 'LineWidth', 1.5 );
plot( 0:s, squeeze( IRsort( 3, 2, :, bands( 2 ) ) ) * scale_adj( 3, 2 ), 'k-', 'LineWidth', 3 );
hold off;

figure, box on; ylim( [-0.50001, 1.00001] );
set( gca, 'FontSize', 16, 'FontName', 'Times New Roman' );
hold on;
plot( 0:s, squeeze( IRsort( 1, 2, :, bands( 2 ) ) ) * scale_adj( 1, 2 ), 'k--', 'LineWidth', 3 );
plot( 0:s, squeeze( IRsort( 2, 2, :, bands( 2 ) ) ) * scale_adj( 2, 2 ), 'k-', 'LineWidth', 3 );
hold off;

